Module installation

Module installation 

Structs

NewParseInstallation
Represents a new Parse Installation to be created.
RetrievedParseInstallation
Represents a Parse Installation object retrieved from the server.
UpdateParseInstallation
Represents the fields that can be updated on an existing Parse Installation. All fields are optional, allowing for partial updates.

Enums

DeviceType
Represents the type of device for an installation.